# coding: utf-8
from django.conf import settings
from django.db.models.signals import class_prepared
from django.dispatch import Signal
from managers import DataLoggingManager

__author__ = 'Andrey Torsunov'
__contact__ = 'torsunov@bars-open.com'
__docformat__ = 'restructuredtext'


suspects = set(settings.DATALOGGER_SUSPECTS_MODEL)


# Сигналы определяющие поведение методов логгера
# =====================================================================

post_snapshot = Signal(providing_args=['log_record'])
post_system_event = Signal(providing_args=['log_record'])
custom_log_context = Signal(providing_args=['request'])
custom_verbose = Signal(
    providing_args=['log_record', 'model_instance', 'fields_dict'])


def add_datalogger_manager(sender, **kw):
    u""" Обработчик сигнала class_prepared. 

    Если модель указана в списке ``DATALOGGER_SUSPECTS_MODEL``, то 
    обработчик добавляет в класс модели ``DataLoggingManager``.

    """
    cls = sender
    full_path = '{0}.{1}'.format(cls.__module__, cls.__name__)
    short_path = '{0}.{1}'.format(cls._meta.app_label, cls.__name__)
    if suspects.intersection((short_path, full_path)):
        cls.add_to_class(settings.DATALOGGER_MANAGER_NAME, DataLoggingManager())


class_prepared.connect(add_datalogger_manager, weak=False)
